==> sx-dbutils-1.2.5-sources.jar: jp/sourceforge/sxdbutils/rstable/TimestampColumn.java <==
package jp.sourceforge.sxdbutils.rstable;

import java.math.BigDecimal;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Date;

import jp.sourceforge.sxdbutils.util.SqlDateUtils;

public class TimestampColumn extends AbstractColumn/*<Timestamp>*/{

	public TimestampColumn(int columnIndex, ResultColumnMetaData columnMeta) {
		super(columnIndex, columnMeta);
	}

	public Object valueOf(ResultSet rset) throws SQLException {
		return rset.getTimestamp(columnIndex + 1);
	}

	public BigDecimal getBigDecimal(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return BigDecimal.valueOf(((Timestamp) value).getTime());
	}

	public boolean getBoolean(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		return value != null;
	}

	public Boolean getBooleanObject(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return Boolean.valueOf(value != null);

	}

	public byte getByte(Object[] rowdata) {
		return 0;
	}

	public Byte getByteObject(Object[] rowdata) {
		return null;
	}

	public byte[] getBytes(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return new byte[0];

	}

	public char getChar(Object[] rowdata) {
		return '\u0000';
	}

	public Character getCharacter(Object[] rowdata) {
		return null;
	}

	public Date getDate(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		return ((Timestamp) value);
	}

	public double getDouble(Object[] rowdata) {
		return 0d;
	}

	public Double getDoubleObject(Object[] rowdata) {
		return null;
	}

	public float getFloat(Object[] rowdata) {
		return 0f;
	}

	public Float getFloatObject(Object[] rowdata) {
		return null;
	}

	public int getInt(Object[] rowdata) {
		return 0;
	}

	public Integer getInteger(Object[] rowdata) {
		return null;
	}

	public long getLong(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return 0L;
		return ((Timestamp) value).getTime();
	}

	public Long getLongObject(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return new Long(((Timestamp) value).getTime());
	}

	public short getShort(Object[] rowdata) {
		return (short) 0;
	}

	public Short getShortObject(Object[] rowdata) {
		return null;
	}

	public java.sql.Date getSqlDate(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return SqlDateUtils.toSqlDate(((Timestamp) value).getTime());
	}

	public String getString(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return value.toString();
	}

	public Time getTime(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return SqlDateUtils.toSqlTime(((Timestamp) value).getTime());
	}

	public Timestamp getTimestamp(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		return ((Timestamp) value);
	}

}

==> sx-dbutils-1.3.1-sources.jar: jp/sourceforge/sxdbutils/rstable/TimestampColumn.java <==
package jp.sourceforge.sxdbutils.rstable;

import java.math.BigDecimal;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Date;

import jp.sourceforge.sxdbutils.util.SqlDateUtils;

public class TimestampColumn extends AbstractColumn/*<Timestamp>*/{

	public TimestampColumn(int columnIndex, ResultColumnMetaData columnMeta) {
		super(columnIndex, columnMeta);
	}

	public Object valueOf(ResultSet rset) throws SQLException {
		return rset.getTimestamp(columnIndex + 1);
	}

	public BigDecimal getBigDecimal(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return BigDecimal.valueOf(((Timestamp) value).getTime());
	}

	public boolean getBoolean(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		return value != null;
	}

	public Boolean getBooleanObject(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return Boolean.valueOf(value != null);

	}

	public byte getByte(Object[] rowdata) {
		return 0;
	}

	public Byte getByteObject(Object[] rowdata) {
		return null;
	}

	public byte[] getBytes(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return new byte[0];

	}

	public char getChar(Object[] rowdata) {
		return '\u0000';
	}

	public Character getCharacter(Object[] rowdata) {
		return null;
	}

	public Date getDate(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return new java.util.Date(((((Timestamp) value).getTime() / 1000) * 1000) + ((Timestamp) value).getNanos()
				/ 1000000);
	}

	public double getDouble(Object[] rowdata) {
		return 0d;
	}

	public Double getDoubleObject(Object[] rowdata) {
		return null;
	}

	public float getFloat(Object[] rowdata) {
		return 0f;
	}

	public Float getFloatObject(Object[] rowdata) {
		return null;
	}

	public int getInt(Object[] rowdata) {
		return 0;
	}

	public Integer getInteger(Object[] rowdata) {
		return null;
	}

	public long getLong(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return 0L;
		return ((Timestamp) value).getTime();
	}

	public Long getLongObject(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return new Long(((Timestamp) value).getTime());
	}

	public short getShort(Object[] rowdata) {
		return (short) 0;
	}

	public Short getShortObject(Object[] rowdata) {
		return null;
	}

	public java.sql.Date getSqlDate(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return SqlDateUtils.toSqlDate(((Timestamp) value).getTime());
	}

	public String getString(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return value.toString();
	}

	public Time getTime(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		if (value == null)
			return null;
		return SqlDateUtils.toSqlTime(((Timestamp) value).getTime());
	}

	public Timestamp getTimestamp(Object[] rowdata) {
		Object value = rowdata[columnIndex];
		return ((Timestamp) value);
	}

}
